@@ -44,7 +44,7 @@ class PmAgentClient(metaclass=ABCMeta):
             await self.bot.send(f"No active users with agent for {self.norm}!", self.uid)
             raise Exception(f"No active users for {self.norm}!")
 
-        self.browser = await pw.chromium.launch(channel="chrome", headless=not headed)
+        self.browser = await pw.chromium.launch(channel="chromium-headless-shell", headless=not headed)
         context = await self.browser.new_context(storage_state=self.agent.state)
         self.page = await context.new_page()
         await self.page.goto(self.pages.SEND)  # Оптимистично переходим сразу на страницу отправки
