@@ -1,3 +1,4 @@
+import logging
 from asyncio import run
 from datetime import datetime
 from decimal import Decimal
@@ -7,7 +8,7 @@ from time import sleep
 
 from asyncpg.pgproto.pgproto import timedelta
 from payeer_api import PayeerAPI
-from playwright.async_api import async_playwright, Playwright
+from playwright.async_api import async_playwright, Playwright, Error
 from playwright._impl._errors import TimeoutError
 
 from xync_client.loader import TORM
@@ -39,23 +40,22 @@ class Client(PmAgentClient):
         await self.page.goto(self.pages.SEND)
 
     async def send(self, dest: str, amount: int, cur: str) -> tuple[int, bytes, int] | int:
+        self.last_active = datetime.now()
         page = self.page
         if not page.url.startswith(self.pages.SEND):
             try:
                 await page.goto(self.pages.SEND)
-            except TimeoutError:
+            except (TimeoutError, Error):
                 await login(self.agent)
                 for cookie in self.agent.state["cookies"]:
                     await page.context.add_cookies([cookie])
+                sleep(0.5)
                 await page.goto("https://payeer.com/en/account/send/")
-        fiat_accounts = await page.locator(
-            f".balance-item.balance-item--green.balance-item--{cur.lower()}"
-        ).all_text_contents()
-        has_amount = float(fiat_accounts[0].replace(",", "").strip())
+        has_amount = float(self.api.get_balance()[cur]["DOSTUPNO"])
         if float(amount) <= has_amount:
             await page.locator('input[name="param_ACCOUNT_NUMBER"]').fill(dest)
             await page.locator("select[name=curr_receive]").select_option(value=cur)
-            sleep(0.9)
+            sleep(0.8)
             await page.locator('input[name="sum_receive"]').fill(str(amount))
             sleep(0.1)
             # await page.locator("div.n-form--title").first.click()
@@ -63,12 +63,17 @@ class Client(PmAgentClient):
             await page.click(".btn.n-form--btn.n-form--btn-mod")
             sleep(0.5)
             await page.click(".btn.n-form--btn.n-form--btn-mod")
-            sleep(1.2)
+            sleep(1.1)
             if await page.locator(".input4").count():
                 await page.locator(".input4").fill(self.agent.auth.get("master_key"))
                 await page.click(".ok.button_green2")
-            sleep(0.4)
-            await page.locator(".note_txt").wait_for(state="visible")
+            sleep(1)
+            try:
+                await page.locator(".note_txt").wait_for(state="visible", timeout=6000)
+            except TimeoutError as _:
+                logging.error("Repeat!")
+                sleep(0.5)
+                return await self.send(dest, amount, cur)
             if await page.locator('.note_txt:has-text("successfully completed")').count():
                 transaction = await page.locator(".note_txt").all_text_contents()
                 trans_num = int(transaction[0].replace("Transaction #", "").split()[0])
@@ -76,7 +81,7 @@ class Client(PmAgentClient):
                 await page.click(f".history-id-{trans_num} a.link")
                 sleep(1)
                 receipt = await page.query_selector(".ui-dialog.ui-corner-all")
-                return trans_num, await receipt.screenshot(path=f"tmp/{dest}.png"), has_amount - amount
+                return trans_num, await receipt.screenshot(path=f"tmp/{dest}.png"), int(has_amount - amount)
             else:
                 await self.bot.send("Payeer хз", self.uid, photo=await self.page.screenshot())
                 return -1
@@ -119,7 +124,7 @@ async def main(uid: int):
     playwright: Playwright = await async_playwright().start()
     pyr = Client(uid)
     try:
-        await pyr.start(playwright, True)
+        await pyr.start(playwright, False)
 
         dest, amount, cur = "P79619335", 2, "RUB"
 
@@ -146,4 +151,4 @@ async def main(uid: int):
 
 
 if __name__ == "__main__":
-    run(main(193017646))
+    run(main(1779829771))
