@@ -8,7 +8,14 @@ import time
 
 
 async def login(agent: PmAgent):
-    driver = uc.Chrome(no_sandbox=True, headless=False)
+    options = uc.ChromeOptions()
+    options.add_argument("--disable-blink-features=AutomationControlled")
+    options.add_argument("--no-sandbox")
+    options.add_argument("--disable-dev-shm-usage")
+    options.add_argument("--window-size=1920,1080")
+    options.add_argument("--user-agent=Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36")
+
+    driver = uc.Chrome(options=options, headless=True)
     wait = WebDriverWait(driver, timeout=10)
     try:
         driver.get("https://payeer.com/en/auth")
@@ -21,8 +28,11 @@ async def login(agent: PmAgent):
         password_field.send_keys(agent.auth.get("password"))
         login_button = wait.until(EC.element_to_be_clickable((By.CLASS_NAME, "login-form__login-btn.step1")))
         login_button.click()
-        time.sleep(5)
-        login_button.click()
+        time.sleep(4)
+        try:
+            login_button.click()
+        except Exception:
+            pass
         time.sleep(1)
         if (v := driver.find_elements(By.CLASS_NAME, "form-input-top")) and v[0].text == "Введите проверочный код":
             code = input("Email code: ")
